==> is-valid-css-unit-1.1.0.tgz: package/es/index.js <==
/**
 * Font Units
 * Reference: https://developer.mozilla.org/en-US/docs/Web/CSS/length#Font-relative_lengths
 * @constant
 * @type {Array.<string>}
 * @default
 * @public
 */
export var FONT_UNITS = ['cap', 'ch', 'em', 'ex', 'ic', 'lh', 'rem', 'rlh'];

/**
 * Percentage Units
 * https://developer.mozilla.org/en-US/docs/Web/CSS/percentage#Syntax
 * @constant
 * @type {Array.<string>}
 * @default
 * @public
 */
export var PERCENTAGE_UNITS = ['%'];

/**
 * Angle Units
 * https://developer.mozilla.org/en-US/docs/Web/CSS/angle#Units
 * @constant
 * @type {Array.<string>}
 * @default
 * @public
 */
export var ANGLE_UNITS = ['deg', 'grad', 'rad', 'turn'];

/**
 * Viewport Units
 * https://developer.mozilla.org/en-US/docs/Web/CSS/length#Viewport-percentage_lengths
 * @constant
 * @type {Array.<string>}
 * @default
 * @public
 */
export var VIEWPORT_UNITS = ['vh', 'vw', 'vi', 'vb', 'vmin', 'vmax'];

/**
 * Absolute Units
 * https://developer.mozilla.org/en-US/docs/Web/CSS/length#Absolute_length_units
 * @constant
 * @type {Array.<string>}
 * @default
 * @public
 */
export var ABSOLUTE_UNITS = ['px', 'cm', 'mm', 'Q', 'in', 'pc', 'pt', 'mozmm'];

/**
 * Time Units
 * https://developer.mozilla.org/en-US/docs/Web/CSS/time#Units
 * @constant
 * @type {Array.<string>}
 * @default
 * @public
 */
export var TIME_UNITS = ['s', 'ms'];

/**
 * Frequency Units
 * https://developer.mozilla.org/en-US/docs/Web/CSS/frequency#Units
 * @constant
 * @type {Array.<string>}
 * @default
 * @public
 */
export var FREQUENCY_UNITS = ['Hz', 'kHz'];

/**
 * Resolution Units
 * https://developer.mozilla.org/en-US/docs/Web/CSS/resolution#Units
 * @constant
 * @type {Array.<string>}
 * @default
 * @public
 */
export var RESOLUTION_UNITS = ['dpi', 'dpcm', 'dppx', 'x'];

/**
 * All CSS Units
 * @constant
 * @type {Array.<string>}
 * @default
 * @public
 */
export var ALL_UNITS = [].concat(FONT_UNITS, TIME_UNITS, ANGLE_UNITS, VIEWPORT_UNITS, ABSOLUTE_UNITS, FREQUENCY_UNITS, PERCENTAGE_UNITS, RESOLUTION_UNITS);

/**
 * Creates and returns a regular expression that matches valid numbers and CSS units.
 * @param {Array} units - CSS units to match for.
 * @returns {RegExp}
 */
var generateRegExp = function generateRegExp() {
  var units = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  return new RegExp('(^[\\+\\-]?\\.?[0-9]+[e\\-]?\\.?)?[0-9]+(e\\-[0-9])?(' + units.join('|') + ')?$', 'i');
};

/**
 * Regular expression that matches for any kind of CSS unit.
 * @type {RegExp}
 */
var allRegexp = generateRegExp(ALL_UNITS);

/**
 * Regular expression that matches CSS font units.
 * @type {RegExp}
 */
var fontRegexp = generateRegExp(FONT_UNITS);

/**
 * Regular expression that matches CSS time units.
 * @type {RegExp}
 */
var timeRegexp = generateRegExp(TIME_UNITS);

/**
 * Regular expression that matches CSS angle units.
 * @type {RegExp}
 */
var angleRegexp = generateRegExp(ANGLE_UNITS);

/**
 * Regular expression that matches CSS viewport units.
 * @type {RegExp}
 */
var viewportRegexp = generateRegExp(VIEWPORT_UNITS);

/**
 * Regular expression that matches CSS absolute units.
 * @type {RegExp}
 */
var absoluteRegexp = generateRegExp(ABSOLUTE_UNITS);

/**
 * Regular expression that matches  CSS frequency units.
 * @type {RegExp}
 */
var frequencyRegexp = generateRegExp(FREQUENCY_UNITS);

/**
 * Regular expression that matches  CSS percentage units.
 * @type {RegExp}
 */
var percentageRegexp = generateRegExp(PERCENTAGE_UNITS);

/**
 * Regular expression that matches CSS resolution units.
 * @type {RegExp}
 */
var resolutionRegexp = generateRegExp(RESOLUTION_UNITS);

/**
 * Tests a value to see if it's a valid CSS font unit
 * @param {String} value
 * @returns {Boolean}
 * @public
 */
export var isFontUnit = function isFontUnit(value) {
  return fontRegexp.test(value);
};

/**
 * Tests a value to see if it's a valid CSS time unit
 * @param {String} value
 * @returns {Boolean}
 * @public
 */
export var isTimeUnit = function isTimeUnit(value) {
  return timeRegexp.test(value);
};

/**
 * Tests a value to see if it's a valid CSS angle unit
 * @param {String} value
 * @returns {Boolean}
 * @public
 */
export var isAnglegeUnit = function isAnglegeUnit(value) {
  return angleRegexp.test(value);
};

/**
 * Tests a value to see if it's a valid CSS viewport unit
 * @param {String} value
 * @returns {Boolean}
 * @public
 */
export var isViewportUnit = function isViewportUnit(value) {
  return viewportRegexp.test(value);
};

/**
 * Tests a value to see if it's a valid CSS absolute unit
 * @param {String} value
 * @returns {Boolean}
 * @public
 */
export var isAbsoluteUnit = function isAbsoluteUnit(value) {
  return absoluteRegexp.test(value);
};

/**
 * Tests a value to see if it's a valid CSS frequency unit
 * @param {String} value
 * @returns {Boolean}
 * @public
 */
export var isFrequencyUnit = function isFrequencyUnit(value) {
  return frequencyRegexp.test(value);
};

/**
 * Tests a value to see if it's a valid CSS percentage unit
 * @param {String} value
 * @returns {Boolean}
 * @public
 */
export var isPercentageUnit = function isPercentageUnit(value) {
  return percentageRegexp.test(value);
};

/**
 * Tests a value to see if it's a valid CSS resolution unit
 * @param {String} value
 * @returns {Boolean}
 * @public
 */
export var isResolutionUnit = function isResolutionUnit(value) {
  return resolutionRegexp.test(value);
};

/**
 * Tests a value to see if it's a valid CSS unit
 * @param {String} value
 * @returns {Boolean}
 * @public
 */
export default (function (value) {
  return allRegexp.test(value);
});

==> is-valid-css-unit-1.2.0.tgz: package/es/index.js <==
/**
 * Font Units
 * Reference: https://developer.mozilla.org/en-US/docs/Web/CSS/length#Font-relative_lengths
 * @constant
 * @type {Array.<string>}
 * @default
 * @public
 */
export var FONT_UNITS = ['cap', 'ch', 'em', 'ex', 'ic', 'lh', 'rem', 'rlh'];

/**
 * Percentage Units
 * https://developer.mozilla.org/en-US/docs/Web/CSS/percentage#Syntax
 * @constant
 * @type {Array.<string>}
 * @default
 * @public
 */
export var PERCENTAGE_UNITS = ['%'];

/**
 * Angle Units
 * https://developer.mozilla.org/en-US/docs/Web/CSS/angle#Units
 * @constant
 * @type {Array.<string>}
 * @default
 * @public
 */
export var ANGLE_UNITS = ['deg', 'grad', 'rad', 'turn'];

/**
 * Viewport Units
 * https://developer.mozilla.org/en-US/docs/Web/CSS/length#Viewport-percentage_lengths
 * @constant
 * @type {Array.<string>}
 * @default
 * @public
 */
export var VIEWPORT_UNITS = ['vh', 'vw', 'vi', 'vb', 'vmin', 'vmax'];

/**
 * Absolute Units
 * https://developer.mozilla.org/en-US/docs/Web/CSS/length#Absolute_length_units
 * @constant
 * @type {Array.<string>}
 * @default
 * @public
 */
export var ABSOLUTE_UNITS = ['px', 'cm', 'mm', 'Q', 'in', 'pc', 'pt', 'mozmm'];

/**
 * Time Units
 * https://developer.mozilla.org/en-US/docs/Web/CSS/time#Units
 * @constant
 * @type {Array.<string>}
 * @default
 * @public
 */
export var TIME_UNITS = ['s', 'ms'];

/**
 * Frequency Units
 * https://developer.mozilla.org/en-US/docs/Web/CSS/frequency#Units
 * @constant
 * @type {Array.<string>}
 * @default
 * @public
 */
export var FREQUENCY_UNITS = ['Hz', 'kHz'];

/**
 * Resolution Units
 * https://developer.mozilla.org/en-US/docs/Web/CSS/resolution#Units
 * @constant
 * @type {Array.<string>}
 * @default
 * @public
 */
export var RESOLUTION_UNITS = ['dpi', 'dpcm', 'dppx', 'x'];

/**
 * All CSS Units
 * @constant
 * @type {Array.<string>}
 * @default
 * @public
 */
export var ALL_UNITS = [].concat(FONT_UNITS, TIME_UNITS, ANGLE_UNITS, VIEWPORT_UNITS, ABSOLUTE_UNITS, FREQUENCY_UNITS, PERCENTAGE_UNITS, RESOLUTION_UNITS);

/**
 * Creates and returns a regular expression that matches valid numbers and CSS units.
 * @param {Array} units - CSS units to match for.
 * @returns {RegExp}
 */

var generateRegExp = function generateRegExp() {
  var units = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  return new RegExp('^[\\-\\+]?(?!00|0\\d)(\\.?[0-9]+[e\\-\\+]?\\.?)?[0-9]+(e[\\-\\+]?[0-9])?(' + units.join('|') + ')?$', 'i');
};

/**
 * Regular expression that matches for any kind of CSS unit.
 * @type {RegExp}
 */
var allRegexp = generateRegExp(ALL_UNITS);

/**
 * Regular expression that matches CSS font units.
 * @type {RegExp}
 */
var fontRegexp = generateRegExp(FONT_UNITS);

/**
 * Regular expression that matches CSS time units.
 * @type {RegExp}
 */
var timeRegexp = generateRegExp(TIME_UNITS);

/**
 * Regular expression that matches CSS angle units.
 * @type {RegExp}
 */
var angleRegexp = generateRegExp(ANGLE_UNITS);

/**
 * Regular expression that matches CSS viewport units.
 * @type {RegExp}
 */
var viewportRegexp = generateRegExp(VIEWPORT_UNITS);

/**
 * Regular expression that matches CSS absolute units.
 * @type {RegExp}
 */
var absoluteRegexp = generateRegExp(ABSOLUTE_UNITS);

/**
 * Regular expression that matches  CSS frequency units.
 * @type {RegExp}
 */
var frequencyRegexp = generateRegExp(FREQUENCY_UNITS);

/**
 * Regular expression that matches  CSS percentage units.
 * @type {RegExp}
 */
var percentageRegexp = generateRegExp(PERCENTAGE_UNITS);

/**
 * Regular expression that matches CSS resolution units.
 * @type {RegExp}
 */
var resolutionRegexp = generateRegExp(RESOLUTION_UNITS);

/**
 * Tests a value to see if it's a valid CSS font unit
 * @param {String} value
 * @returns {Boolean}
 * @public
 */
export var isFontUnit = function isFontUnit(value) {
  return fontRegexp.test(value);
};

/**
 * Tests a value to see if it's a valid CSS time unit
 * @param {String} value
 * @returns {Boolean}
 * @public
 */
export var isTimeUnit = function isTimeUnit(value) {
  return timeRegexp.test(value);
};

/**
 * Tests a value to see if it's a valid CSS angle unit
 * @param {String} value
 * @returns {Boolean}
 * @public
 */
export var isAnglegeUnit = function isAnglegeUnit(value) {
  return angleRegexp.test(value);
};

/**
 * Tests a value to see if it's a valid CSS viewport unit
 * @param {String} value
 * @returns {Boolean}
 * @public
 */
export var isViewportUnit = function isViewportUnit(value) {
  return viewportRegexp.test(value);
};

/**
 * Tests a value to see if it's a valid CSS absolute unit
 * @param {String} value
 * @returns {Boolean}
 * @public
 */
export var isAbsoluteUnit = function isAbsoluteUnit(value) {
  return absoluteRegexp.test(value);
};

/**
 * Tests a value to see if it's a valid CSS frequency unit
 * @param {String} value
 * @returns {Boolean}
 * @public
 */
export var isFrequencyUnit = function isFrequencyUnit(value) {
  return frequencyRegexp.test(value);
};

/**
 * Tests a value to see if it's a valid CSS percentage unit
 * @param {String} value
 * @returns {Boolean}
 * @public
 */
export var isPercentageUnit = function isPercentageUnit(value) {
  return percentageRegexp.test(value);
};

/**
 * Tests a value to see if it's a valid CSS resolution unit
 * @param {String} value
 * @returns {Boolean}
 * @public
 */
export var isResolutionUnit = function isResolutionUnit(value) {
  return resolutionRegexp.test(value);
};

/**
 * Tests a value to see if it's a valid CSS unit
 * @param {String} value
 * @returns {Boolean}
 * @public
 */
export default (function (value) {
  return allRegexp.test(value);
});
